@@@@@@@@@@
dob-bright
@@@@@@@@@@

.. image:: https://travis-ci.com/hotoffthehamster/dob-bright.svg?branch=develop
  :target: https://travis-ci.com/hotoffthehamster/dob-bright
  :alt: Build Status

.. image:: https://codecov.io/gh/hotoffthehamster/dob-bright/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/hotoffthehamster/dob-bright
  :alt: Coverage Status

.. image:: https://readthedocs.org/projects/dob-bright/badge/?version=latest
  :target: https://dob-bright.readthedocs.io/en/latest/
  :alt: Documentation Status

.. image:: https://img.shields.io/github/release/hotoffthehamster/dob-bright.svg?style=flat
  :target: https://github.com/hotoffthehamster/dob-bright/releases
  :alt: GitHub Release Status

.. image:: https://img.shields.io/pypi/v/dob-bright.svg
  :target: https://pypi.org/project/dob-bright/
  :alt: PyPI Release Status

.. image:: https://img.shields.io/github/license/hotoffthehamster/dob-bright.svg?style=flat
  :target: https://github.com/hotoffthehamster/dob-bright/blob/master/LICENSE
  :alt: License Status

.. |dob| replace:: ``dob``
.. _dob: https://github.com/hotoffthehamster/dob

.. |dob-docs| replace:: Dob documentation
.. _dob-docs: https://dob.readthedocs.io/en/latest/

.. |dob-bright| replace:: ``dob-bright``
.. _dob-bright: https://github.com/hotoffthehamster/dob-bright

|dob-bright|_ is a component of |dob|_,  an interactive, terminal-based,
time tracking, journaling, note-taking, and life-hacking application.

|dob-bright|_ provides the basic, non interesting functionality used
by the various |dob|_ components, such as the CLI user configuration
settings, the ``nark.Control`` shim, some basic terminal I/O methods,
and some (packaged) test infrastructure shared with other projects.

Please see the |dob-docs|_ for lots more help and instruction.


